==> cutemaze-1.1.1-2-src.tar.xz: cutemaze-1.1.1/translations/cutemaze_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="170"/>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="170"/>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Önceki oyunu yüklemede hata. Yeni bir oyun başlatılacak.</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="445"/>
        <source>%1 elapsed</source>
        <translation>Geçen süre: %1</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="446"/>
        <source>%1 steps taken</source>
        <translation>%1 adım atıldı</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="447"/>
        <source>%1 of %2 targets remain</source>
        <translation>%1/%2 hedef kaldı</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="778"/>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="795"/>
        <source>Paused</source>
        <translation>Durdu</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <location filename="../src/settings.cpp" line="119"/>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="123"/>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="126"/>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="129"/>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="134"/>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="136"/>
        <source>Windows</source>
        <translation>Pencereler</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="141"/>
        <source>Command</source>
        <translation>Komut</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="144"/>
        <source>Control</source>
        <translation>Kontrol</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="147"/>
        <source>Option</source>
        <translation>Seçenek</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Uygulama dilini seçiniz:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistem Dili&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>Önemli</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Değişikliklerin geçerli olabilmesi için bu uygulamayı tekrar başlatınız.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="35"/>
        <source>New Game</source>
        <translation>Yeni Oyun</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="43"/>
        <source>Hunt and Kill</source>
        <translation>Avla ve Yoket</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="44"/>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="45"/>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="46"/>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="47"/>
        <source>Stack</source>
        <translation>Yığın</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="48"/>
        <source>Stack 2</source>
        <translation>Yığın 2</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="49"/>
        <source>Stack 3</source>
        <translation>Yığın 3</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="50"/>
        <source>Stack 4</source>
        <translation>Yığın 4</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="51"/>
        <source>Stack 5</source>
        <translation>Yığın 5</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="73"/>
        <source>Algorithm:</source>
        <translation>Algoritma:</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="74"/>
        <source>Targets:</source>
        <translation>Hedefler:</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="75"/>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <location filename="../src/scores.cpp" line="77"/>
        <source>Hunt and Kill</source>
        <translation>Avla ve Yoket</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="78"/>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="79"/>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="80"/>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="81"/>
        <source>Stack</source>
        <translation>Yığın</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="82"/>
        <source>Stack 2</source>
        <translation>Yığın 2</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="83"/>
        <source>Stack 3</source>
        <translation>Yığın 3</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="84"/>
        <source>Stack 4</source>
        <translation>Yığın 4</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="85"/>
        <source>Stack 5</source>
        <translation>Yığın 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <location filename="../src/scores.cpp" line="99"/>
        <source>CuteMaze Scores</source>
        <translation>Skor Tablosu</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="108"/>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="108"/>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="108"/>
        <source>Time</source>
        <translation>Zaman</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="108"/>
        <source>Steps</source>
        <translation>Adımlar</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="108"/>
        <source>Algorithm</source>
        <translation>Algoritma</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="108"/>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="160"/>
        <source>Congratulations!</source>
        <translation>Tebrikler!</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="160"/>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>İlk 10&apos;a girdiniz.\nLütfen adınızı giriniz:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/settings.cpp" line="192"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="209"/>
        <source>Game</source>
        <translation>Oyun</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="211"/>
        <source>Show where you&apos;ve been</source>
        <translation>İzleri göster</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="212"/>
        <source>Show number of steps taken</source>
        <translation>Adım sayısını göster</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="213"/>
        <source>Show elapsed time</source>
        <translation>Geçen süreyi göster</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="214"/>
        <source>Smooth movement</source>
        <translation>Yumuşak ilerleme</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="225"/>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="234"/>
        <source>Move Up:</source>
        <translation>Yukarı:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="235"/>
        <source>Move Down:</source>
        <translation>Aşağı:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="236"/>
        <source>Move Left:</source>
        <translation>Sola:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="237"/>
        <source>Move Right:</source>
        <translation>Sağa:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="238"/>
        <source>Toggle Flag:</source>
        <translation>İz bayrağı:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="243"/>
        <source>Themes</source>
        <translation>Temalar</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="254"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="256"/>
        <source>Remove</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="320"/>
        <source>Select Theme File</source>
        <translation>Tema Dosyasını Seç</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="330"/>
        <location filename="../src/settings.cpp" line="338"/>
        <location filename="../src/settings.cpp" line="371"/>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="330"/>
        <source>Unable to create data folder.</source>
        <translation>Veri klasörü oluşturulamıyor.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="338"/>
        <source>Unable to copy theme file.</source>
        <translation>Tema dosyası kopyalanamıyor.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="367"/>
        <source>Question</source>
        <translation>Emin Misiniz</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="367"/>
        <source>Remove the selected theme?</source>
        <translation>Seçilen tema silinsin mi?</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="371"/>
        <source>Unable to remove the selected theme.</source>
        <translation>Seçilen tema kaldırılamadı.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="78"/>
        <location filename="../src/window.cpp" line="172"/>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="128"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="130"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="131"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="135"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="137"/>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="138"/>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="140"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="149"/>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="127"/>
        <source>&amp;Game</source>
        <translation>&amp;Oyun</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="128"/>
        <source>&amp;New</source>
        <translation>&amp;Yeni</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="129"/>
        <source>&amp;Pause</source>
        <translation>&amp;Durdur</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="131"/>
        <source>&amp;Hint</source>
        <translation>&amp;İpucu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="133"/>
        <source>High &amp;Scores</source>
        <translation>&amp;Yüksek Skorlar</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="135"/>
        <source>&amp;Quit</source>
        <translation>&amp;Çıkış</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="138"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;Yakınlaştır</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="140"/>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Uzaklaştır</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="143"/>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="144"/>
        <source>Application &amp;Language...</source>
        <translation>&amp;Uygulama Dili...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="145"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Tercihler</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="147"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="148"/>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <source>A top-down maze game</source>
        <translation>Bir Labirent Oyunudur</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="174"/>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="175"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Sürüm &lt;a href=%1&gt;GPL 3&lt;/a&gt; lisansı altındadır.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="176"/>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>İkonlar &lt;a href=%1&gt;Oxygen&lt;/a&gt; temasındandır</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="177"/>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;LGPL 3&lt;/a&gt; lisansı altındadır</translation>
    </message>
</context>
</TS>

==> cutemaze-1.2.1-1-src.tar.xz: cutemaze-1.2.1/translations/cutemaze_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Önceki oyunu yüklemede hata. Yeni bir oyun başlatılacak.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>Geçen süre: %1</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 adım atıldı</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1/%2 hedef kaldı</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Durdu</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Süper</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Pencereler</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Komut</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Kontrol</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Seçenek</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Uygulama dilini seçin:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistem Dili&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Önemli</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Değişikliklerin geçerli olabilmesi için bu uygulamayı tekrar başlatınız.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Yeni Oyun</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Avla ve Öldür</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Yığın</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Yığın 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Yığın 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Yığın 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Yığın 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritma:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Hedefler:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Avla ve Öldür</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Yığın</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Yığın 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Yığın 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Yığın 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Yığın 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Skor Tablosu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Zaman</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Adımlar</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritma</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Tebrikler!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>İlk 10&apos;a girdiniz.
Lütfen adınızı girin:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Oyun</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>İzleri göster</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Adım sayısını göster</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Geçen süreyi göster</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Yumuşak ilerleme</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Yukarı:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Aşağı:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Sola:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Sağa:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>İz bayrağı:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temalar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Çıkar</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Tema Dosyasını Seçin</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Veri klasörü oluşturulamıyor.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Tema dosyası kopyalanamıyor.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Seçilen tema silinsin mi?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Seçilen tema kaldırılamadı.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Oyun</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Yeni</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Durdur</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;İpucu</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Yüksek Skorlar</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çıkış</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Uzaklaştır</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Uygulama Dili...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Tercihler</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Bir Labirent Oyunudur</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Sürüm &lt;a href=%1&gt;GPL 3&lt;/a&gt; lisansı altındadır.</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>İkonlar &lt;a href=%1&gt;Oxygen&lt;/a&gt; temasındandır</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;LGPL 3&lt;/a&gt; lisansı altındadır</translation>
    </message>
</context>
</TS>
